@@ -300,7 +300,7 @@ impl LogsState {
         .iter_mut()
         // Only wrap the records we could potentially be displaying
         .skip(lines_to_skip)
-        .map(|r| {
+        .flat_map(|r| {
           // See if we can use a cached wrapped line
           if let Some(wrapped) = &r.1 {
             if wrapped.1 as usize == logs_area_width {
@@ -322,8 +322,7 @@ impl LogsState {
 
           wrapped_lines_len += r.1.as_ref().unwrap().0.len();
           r.1.as_ref().unwrap().0.clone()
-        })
-        .flatten(),
+        }),
     );
 
     let wrapped_lines_to_skip = if follow {
